/* TokenLst.h -- module containing Token List ADT and token scanner
 *
 * Author: Dylan Muir
 * Created: 29th September, 1998
 * Modified: 14th September, 1999
 * Version: 1.11
 *
 * Description: A tokenlist is an ordered list of tokens.  A token list is maintained in the
 *              same order as the tokens were added.  Tokens are separated by whitespace.
 */

#ifndef	__TOKENLST_H
#define	__TOKENLST_H

/* -- TokenList data structure -- */

struct tokenListTag {
	char	*token;			/* Token text */

   struct tokenListTag	*NEXT;		/* Next token */
};

typedef struct tokenListTag	tokenList;


/* -- TokenList support functions -- */

/* -- Function GetTokens
 * Pre: 'text' is a valid string
 * Post: (All tokens were scanned from 'text' and returned as a list) ||
 *       (the operation was unsuccesful && NULL was returned)
 */
tokenList *GetTokens(char *text);

/* -- Function AddToken
 * Pre: 'tokenText' is a valid string && 'list' is a valid TokenList
 * Post: A token containing 'tokenText' was allocated and added to the end of 'list'
 */
tokenList *AddToken(char tokenText[], tokenList *list);

/* -- Function DestroyTokenList
 * Pre: 'list' is a valid TokenList
 * Post: 'list' was deallocated && an empty TokenList was returned
 */
tokenList *DestroyTokenList(tokenList *list);


/* -- Function ConcatenateTokenList
 * Pre: 'list1' and 'list2' are valid TokenLists
 * Post: 'list2' was appended to 'list1' and the resulting list was returned
 */
tokenList *ConcatenateTokenList(tokenList *list1, tokenList *list2);

/* -- Function TokenListLength
 * Pre: 'list' is a valid NULL-terminated token list
 * Post: the length of 'list' has been counted and was returned
 */
int TokenListLength(tokenList *list);

#endif	/* __TOKENLST_H */
