/* vector read: utilities for reading a vector
 *
 * SEE vector_read.h for details
 */


/* -- vector read includes -- */

#include "vector_utils.h"
#include "stddefs.h"
#include <stdio.h>
#include "tokenlst.h"
#include "tokscan.h"
#include <stdlib.h>


/* -- internal structures -- */

/* -- vector read functions -- */

vector *VectorReadLine(FILE *input, bool *inFile)
{
	tokenList	*tokens, *tindex;
	vector		*vect;
	int		dimensions, compIndex;

	*inFile = !feof(input);

	tokens = ReadLineTokens(input, inFile);

	if (tokens == NULL) return NULL;		/* nothing on the line */

	dimensions = TokenListLength(tokens);
	if ((vect = VectorAllocate(dimensions)) == NULL) {
		DestroyTokenList(tokens);
		return NULL;
	}

	tindex = tokens;
	compIndex = 0;
	while ((compIndex < dimensions) && (tindex != NULL)) {
		vect -> components[compIndex] = atof(tindex -> token);
		tindex = tindex -> NEXT;
		compIndex++;
	}

	DestroyTokenList(tokens);

	return vect;
}


void VectorReadComponents(FILE *input, vector *vect, bool *inFile)
{
	tokenList	*tokens, *tindex;
	int		dimensions, compIndex;

	*inFile = !feof(input);

	tokens = ReadLineTokens(input, inFile);

	if (tokens == NULL) return;		/* nothing on the line */

	dimensions = vect -> dimensions;

	tindex = tokens;
	compIndex = 0;
	while ((compIndex < dimensions) && (tindex != NULL)) {
		vect -> components[compIndex] = atof(tindex -> token);
		tindex = tindex -> NEXT;
		compIndex++;
	}

	DestroyTokenList(tokens);
}

void VectorWrite(FILE *output, vector *vect)
{
	int	dIndex;			/* index into dimensions */

	dIndex = 0;
	while(dIndex < vect -> dimensions) {
		fprintf(output, "%3.2f\t", vect -> components[dIndex]);
		dIndex++;
	}
}

/* --- END of vector_read.c --- */

